@@ -1031,6 +1031,8 @@ class RealServer(HttpClient, KempBaseObjectModel):
         self.rsport = port
         validate_port(port)
         self.cert = loadmaster_virt_service_info.get("cert")
+        # Needed to modify the RS port on LM
+        self.newport = None
         try:
             self.vs = loadmaster_virt_service_info["vs"]
         except KeyError:
@@ -1070,7 +1072,13 @@ class RealServer(HttpClient, KempBaseObjectModel):
         else:
             response = self._get("/modrs", self.to_api_dict())
         if is_successful(response):
+            # If the rs port is to be changed set it to the new_port value
+            if self.newport:
+                self.rsport = self.newport
             response = self._get("/showrs", self._get_base_parameters())
+            # Set new_port back to none as its only used when the rsport needs
+            # to be changed on the LM
+            self.newport = None
             data = get_data(response)
             rs_data = data.get("Rs", {})
             self.populate_default_attributes(rs_data)
